@@ -27,7 +27,6 @@
 
 #include "eel-art-extensions.h"
 #include "eel-art-gtk-extensions.h"
-#include "eel-debug-drawing.h"
 #include "eel-gtk-container.h"
 #include "eel-gtk-extensions.h"
 #include "eel-accessibility.h"
@@ -41,6 +40,10 @@
 #define DEFAULT_X_ALIGNMENT 0.5
 #define DEFAULT_Y_ALIGNMENT 0.5
 
+#if !GTK_CHECK_VERSION(3,0,0)
+#define gtk_widget_get_preferred_size(x,y,z) gtk_widget_size_request(x,y)
+#endif
+
 /* Signals */
 enum
 {
@@ -731,7 +734,7 @@ labeled_image_get_image_dimensions (const EelLabeledImage *labeled_image)
         return eel_dimensions_empty;
     }
 
-    gtk_widget_size_request (labeled_image->details->image, &image_requisition);
+    gtk_widget_get_preferred_size (labeled_image->details->image, &image_requisition, NULL);
 
     image_dimensions.width = (int) image_requisition.width;
     image_dimensions.height = (int) image_requisition.height;
@@ -757,7 +760,7 @@ labeled_image_get_label_dimensions (const EelLabeledImage *labeled_image)
         return eel_dimensions_empty;
     }
 
-    gtk_widget_size_request (labeled_image->details->label, &label_requisition);
+    gtk_widget_get_preferred_size (labeled_image->details->label, &label_requisition, NULL);
 
     label_dimensions.width = (int) label_requisition.width;
     label_dimensions.height = (int) label_requisition.height;
@@ -852,7 +855,7 @@ eel_labeled_image_get_image_bounds (const EelLabeledImage *labeled_image)
     /* get true real dimensions if we're in fixed height mode */
     if (is_fixed_height (labeled_image) && labeled_image_show_image (labeled_image))
     {
-        gtk_widget_size_request (labeled_image->details->image, &image_requisition);
+        gtk_widget_get_preferred_size (labeled_image->details->image, &image_requisition, NULL);
         image_dimensions.width = (int) image_requisition.width;
         image_dimensions.height = (int) image_requisition.height;
     }
@@ -1098,8 +1101,13 @@ labeled_image_update_alignments (EelLabeledImage *labeled_image)
 
         if (labeled_image->details->fill)
         {
+#if GTK_CHECK_VERSION (3, 16, 0)
+            x_alignment = gtk_label_get_xalign (GTK_LABEL (labeled_image->details->label));
+            y_alignment = gtk_label_get_yalign (GTK_LABEL (labeled_image->details->label));
+#else
             gtk_misc_get_alignment (GTK_MISC (labeled_image->details->label),
                                     &x_alignment, &y_alignment);
+#endif
 
             /* Only the label is shown */
             if (!labeled_image_show_image (labeled_image))
@@ -1135,9 +1143,9 @@ labeled_image_update_alignments (EelLabeledImage *labeled_image)
 
             }
 
-#if GTK_CHECK_VERSION (3, 14, 0)
-            gtk_widget_set_halign (labeled_image->details->label, GTK_ALIGN_CENTER);
-            gtk_widget_set_valign (labeled_image->details->label, GTK_ALIGN_CENTER);
+#if GTK_CHECK_VERSION (3, 16, 0)
+            gtk_label_set_xalign (GTK_LABEL (labeled_image->details->label), x_alignment);
+            gtk_label_set_yalign (GTK_LABEL (labeled_image->details->label), y_alignment);
 #else
             gtk_misc_set_alignment (GTK_MISC (labeled_image->details->label),
                                     x_alignment,
@@ -1153,8 +1161,13 @@ labeled_image_update_alignments (EelLabeledImage *labeled_image)
 
         if (labeled_image->details->fill)
         {
+#if GTK_CHECK_VERSION (3, 0, 0)
+            x_alignment = gtk_widget_get_halign (labeled_image->details->image);
+            y_alignment = gtk_widget_get_valign (labeled_image->details->image);
+#else
             gtk_misc_get_alignment (GTK_MISC (labeled_image->details->image),
                                     &x_alignment, &y_alignment);
+#endif
 
             /* Only the image is shown */
             if (!labeled_image_show_label (labeled_image))
@@ -1189,9 +1202,9 @@ labeled_image_update_alignments (EelLabeledImage *labeled_image)
                 }
             }
 
-#if GTK_CHECK_VERSION (3, 14, 0)
-            gtk_widget_set_halign (labeled_image->details->image, GTK_ALIGN_CENTER);
-            gtk_widget_set_valign (labeled_image->details->image, GTK_ALIGN_CENTER);
+#if GTK_CHECK_VERSION (3, 0, 0)
+            gtk_widget_set_halign (labeled_image->details->image, x_alignment);
+            gtk_widget_set_valign (labeled_image->details->image, y_alignment);
 #else
             gtk_misc_set_alignment (GTK_MISC (labeled_image->details->image),
                                     x_alignment,
